==> tum_esm_utils-1.7.1.tar.gz: tum_esm_utils-1.7.1/README.md <==
# 📦 &nbsp;TUM ESM Python Utilities

This library is a collection of small functions used in our research projects. Here, we can test and document the functions properly instead of every project dealing with this overhead which allows us to reduce the size of the utility directories of individual projects.

Feel free to use it in any other project ✨

[![PyPI](https://img.shields.io/pypi/v/tum-esm-utils?color=f43f5e&label=latest%20release)](https://pypi.org/project/tum-esm-utils)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tum-esm-utils?color=f43f5e&label=supported%20python%20versions)](https://pypi.org/project/tum-esm-utils/)<br/>
[![GitHub](https://img.shields.io/github/license/tum-esm/utils?color=f59e0b)](https://github.com/tum-esm/utils/blob/main/LICENSE)
[![GitHub Workflow Status (with branch)](https://img.shields.io/github/actions/workflow/status/tum-esm/utils/test.yaml?branch=main&label=CI%20tests)](https://github.com/tum-esm/utils/actions/workflows/test.yaml)
[![Code Climate maintainability](https://img.shields.io/codeclimate/maintainability/tum-esm/utils?label=codeclimate%20maintainability%20rating)](https://codeclimate.com/github/tum-esm/utils)

<br/>

## For Users

Install the Python library with:

```bash
poetry add tum_esm_utils
# or
pip install tum_esm_utils
```

Use the API reference at [tum-esm-utils.netlify.app](https://tum-esm-utils.netlify.app).

<br/>

## For Developers

Publish the Package to PyPI:

```bash
poetry build
poetry publish
```

Serve documentation page:

```bash
docsify serve ./docs
```

==> tum_esm_utils-1.8.3.tar.gz: tum_esm_utils-1.8.3/README.md <==
# 📦 &nbsp;TUM ESM Python Utilities

This library is a collection of small functions used in our research projects. Here, we can test and document the functions properly instead of every project dealing with this overhead which allows us to reduce the size of the utility directories of individual projects.

Feel free to use it in any other project ✨

[![PyPI](https://img.shields.io/pypi/v/tum-esm-utils?color=f43f5e&label=latest%20release)](https://pypi.org/project/tum-esm-utils)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tum-esm-utils?color=f43f5e&label=supported%20python%20versions)](https://pypi.org/project/tum-esm-utils/)<br/>
[![GitHub](https://img.shields.io/github/license/tum-esm/utils?color=f59e0b)](https://github.com/tum-esm/utils/blob/main/LICENSE)
[![GitHub Workflow Status (with branch)](https://img.shields.io/github/actions/workflow/status/tum-esm/utils/test.yaml?branch=main&label=CI%20tests)](https://github.com/tum-esm/utils/actions/workflows/test.yaml)
[![Code Climate maintainability](https://img.shields.io/codeclimate/maintainability/tum-esm/utils?label=codeclimate%20maintainability%20rating)](https://codeclimate.com/github/tum-esm/utils)

<br/>

## For Users

Install the Python library with:

```bash
pdm add tum_esm_utils
# or
pip install tum_esm_utils
```

Use the API reference at [tum-esm-utils.netlify.app](https://tum-esm-utils.netlify.app).

<br/>

## For Developers

Publish the Package to PyPI:

```bash
pdm build
pdm publish
```

Open documentation page in dev mode

```bash
cd docs
npm install
npm run dev
```
